Utility functions for soar-core.
Functions
- cleanup_
cache - Cleans up the cache directory.
- get_
extract_ dir - Gets the extract directory path for a given base directory.
- remove_
broken_ symlinks - Removes broken symlinks from bin, desktop, and icons directories.
- setup_
required_ paths - Sets up required directories for soar operation.
- substitute_
placeholders - Substitute placeholders in a string with system/package metadata.